@@ -11,15 +11,18 @@ pub struct Children {
 impl ToTokens for Children {
   fn to_tokens(&self, tokens: &mut proc_macro2::TokenStream) {
     if self.nodes.is_empty() {
-      quote! { vec![] }.to_tokens(tokens);
+      quote! { Default::default() }.to_tokens(tokens);
     } else {
       let mut list = vec![];
 
       for node in self.nodes.iter() {
-        list.push(quote!( #node ));
+        match node {
+          Node::Block(block) => list.push(quote!( .set_node( #block .into() ) )),
+          _ => list.push(quote!( .set( #node ) )),
+        }
       }
 
-      quote! { vec![ #(#list),* ] }.to_tokens(tokens);
+      quote! { ahecha::html::Children::default() #(#list)* }.to_tokens(tokens);
     }
   }
 }
